@@ -948,8 +948,7 @@ static int III_dequantize_sample(struct mpstr *mp, real xr[SBLIMIT][SSLIMIT],int
 	/* 
      * zero part
      */
-    for(i=(&xr[SBLIMIT][0]-xrpnt)>>1;i;i--) {
-      *xrpnt++ = 0.0;
+    while (xrpnt <= &xr[SBLIMIT-1][SSLIMIT-1]) {
       *xrpnt++ = 0.0;
     }
 
@@ -1878,7 +1877,7 @@ static void III_hybrid(struct mpstr *mp, real fsIn[SBLIMIT][SSLIMIT],real tsOut[
 int do_layer3(struct mpstr *mp,unsigned char *pcm_sample,int *pcm_point)
 {
 
-  int gr, ch, ss,clip=0;
+  int gr, ch, ss;
   int scalefacs[39]; /* max 39 for short[13][3] mode, mixed: 38, long: 22 */
   struct III_sideinfo sideinfo;
   struct frame *fr;
@@ -2013,12 +2012,12 @@ int do_layer3(struct mpstr *mp,unsigned char *pcm_sample,int *pcm_point)
 
     for(ss=0;ss<SSLIMIT;ss++) {
       if(single >= 0) {
-        clip += synth_ntom_mono(mp,hybridOut[0][ss],pcm_sample,pcm_point);
+        synth_ntom_mono(mp,hybridOut[0][ss],pcm_sample,pcm_point);
       }
       else {
         int p1 = *pcm_point;
-        clip += synth_ntom(mp,hybridOut[0][ss],0,pcm_sample,&p1);
-        clip += synth_ntom(mp,hybridOut[1][ss],1,pcm_sample,pcm_point);
+        synth_ntom(mp,hybridOut[0][ss],0,pcm_sample,&p1);
+        synth_ntom(mp,hybridOut[1][ss],1,pcm_sample,pcm_point);
       }
     }
   }
